@@ -10,7 +10,7 @@
 // Copyright (C) 2011 mod_csp project
 // License : Apache Licence 2.0
 //
-// version : 0.0.3
+// version : 0.0.4
 //
 // Last modification by kumatiki
 //
@@ -136,8 +136,8 @@ static int gm_getsize(GROWMEM * gm){
 static char * fileRead(apr_pool_t * p,char * filename,int * s)
 {
  apr_file_t *fpr;
-    apr_file_open(&fpr, filename, APR_READ, APR_OS_DEFAULT , p);
- if(fpr==NULL)return NULL;
+     apr_status_t rv = apr_file_open(&fpr, filename, APR_READ, APR_OS_DEFAULT , p);
+ if(rv!=APR_SUCCESS)return NULL;
 
  apr_finfo_t finfo;
     apr_file_info_get(&finfo, APR_FINFO_MIN, fpr);
@@ -317,15 +317,15 @@ static apr_table_t * getPOST(request_rec* r) {
 static int includetenkai(apr_pool_t * p,GROWMEM * buf,char * filename,char * dstdir,request_rec *r)
 {
 
-
  char * dstfile = cat(dstdir,"/",filename,NULL);
 
 
  int size;
  char * buffer = fileRead(p,dstfile,&size);
-
- if(buffer==NULL)
+ if(buffer==NULL){
+  ap_rprintf(r,"<br>File %s is Read Error<br>",dstfile);
   return CSPERROR;
+ }
 
  int i = 0;
  while(i<size){
@@ -379,14 +379,14 @@ static int csptoc(apr_pool_t *p, GROWMEM * ten,char * dstcfile,char * dstdir,GRO
   if(mode==0){
    gm_puts(t1,"ap_rputs(\"");
    while(i<size){
-    if(strncmp((buffer+i),"<%includepath",13)==0){
+    if(strncmp((buffer+i),"<%iparam",8)==0){
      mode = 4;
-     i+=13;
+     i+=8;
      break;
     } else
-    if(strncmp((buffer+i),"<%lib",5)==0){
+    if(strncmp((buffer+i),"<%lparam",8)==0){
      mode = 5;
-     i+=5;
+     i+=8;
      break;
     } else
     if(strncmp((buffer+i),"<%csp",5)==0){
@@ -519,6 +519,8 @@ static int csptoc(apr_pool_t *p, GROWMEM * ten,char * dstcfile,char * dstdir,GRO
 "#define GET		__get__\n"
 "#define POST	__post__\n"
 "#define COOKIE	__cookie__\n"
+"#define HEADER_IN	__r__->headers_in\n"
+"#define HEADER_OUT	__r__->headers_out\n"
 "\n"
 "#define tbl_set(a,b,c)		apr_table_set(a,b,c)\n"
 "#define tbl_add(a,b,c)		apr_table_add(a,b,c)\n"
@@ -587,6 +589,13 @@ static int csptoc(apr_pool_t *p, GROWMEM * ten,char * dstcfile,char * dstdir,GRO
 "///////////////////////////////////////////////////////////////////////\n"
 "//#define hash	apr_hash_t * \n"
 "\n"
+"///////////////////////////////////////////////////////////////////////\n"
+"//		\n"
+"///////////////////////////////////////////////////////////////////////\n"
+"void set_content_type(char * str){\n"
+"  __r__->content_type = stndup(str);\n"
+"}\n"
+"\n"
 "\n"
 "///////////////////////////////////////////////////////////////////////\n"
 "//		table\n"
@@ -945,6 +954,8 @@ static void sessionSet(int * session_index,struct _sessionTable * session,char *
  }
  apr_file_close(fpw);
 }
+# 14 "include.c" 2
+
 
 
 ////////////////////////////////////////////////////////////////////////////////////////////////
@@ -989,7 +1000,8 @@ static int csp_handler(request_rec *r)
     if (strcmp(r->handler, "csp")) {
         return DECLINED;
     }
-    r->content_type = "text/html";
+//    r->content_type = "text/html; charset=Shift_JIS";
+      r->content_type = "text/html";
 
     if (r->header_only)
 	    return OK;
@@ -1104,8 +1116,8 @@ static int csp_handler(request_rec *r)
 			errordispay(r,"link error",errorlog);
 			return   OK;
 		}
-
-	}
+	} else 
+		chdir(folder);
 
 	//go go go
 	apr_dso_handle_t * dso_h = NULL;
@@ -1138,6 +1150,10 @@ static int csp_handler(request_rec *r)
 	if(session_index!=0){
 		sessionSet(&session_index,session,sessionid,p,r);
 	}
+
+	//Location Header in jump to url
+	if(apr_table_get(r->headers_out,"Location")!=NULL)
+		return 302;
 	return OK;
 }
 
